package net.h34t.filemure.controller

import io.javalin.http.Context
import net.h34t.filemure.*
import net.h34t.filemure.repository.SqliteRepository
import net.h34t.filemure.tpl.Frame
import net.h34t.filemure.tpl.Overview
import net.h34t.filemure.tpl.OverviewDocuments

class OverviewController(val modifiers: TemplateModifiers, val repository: SqliteRepository) {

    fun overview(ctx: Context) {
        val session = ctx.requireSession()

        val limboFileCount = repository.getLimboFileCount(accountId = session.id)

        val documents = repository.getDocuments(accountId = session.id)

        val grouped = documents.grouped()

        ctx.tempolin(
            Frame(
                modifiers = modifiers,
                title = "Overview",
                isTarget = true,
                content = Overview(
                    modifiers = modifiers,
                    limboFileCount = limboFileCount.toString(),
                    year = {
                        grouped.entries.sortedByDescending { it.key }.map { year ->
                            YearBlock(
                                year = year.key.toString(),
                                month = {
                                    year.value.entries.sortedByDescending { it.key }.map { month ->
                                        MonthBlock(
                                            year = year.key.toString(),
                                            month = (month.key.ordinal + 1).toString(),
                                            count = month.value.size.toString()
                                        )
                                    }.asSequence()
                                }
                            )
                        }.asSequence()
                    }
                )
            )
        )
    }

    fun overviewCategory(ctx: Context) {
        val session = ctx.requireSession()

        val year = ctx.pathParam("year").toInt()
        val month = ctx.pathParam("month").toInt()

        val documents = repository.getDocumentsByYearMonth(accountId = session.id, year = year, month = month)

        ctx.tempolin(
            Frame(
                modifiers = modifiers,
                title = "Overview",
                isTarget = true,
                content = OverviewDocuments(
                    modifiers = modifiers,
                    category = "$year-$month",
                    document = {
                        documents.sortedBy { it.referenceDate }.map { document ->
                            DocumentBlock(
                                extId = document.extId.value,
                                referenceDate = document.referenceDate.formatHtmlForm(),
                                title = document.title.ifBlank { "untitled" },
                            )
                        }.asSequence()
                    }
                )
            )
        )
    }
}