package net.h34t.filemure.controller

import io.javalin.http.Context
import net.h34t.filemure.TemplateModifiers
import net.h34t.filemure.formatHuman
import net.h34t.filemure.repository.SqliteRepository
import net.h34t.filemure.requireSession
import net.h34t.filemure.tempolin
import net.h34t.filemure.tpl.Frame
import net.h34t.filemure.tpl.Search

class SearchController(val modifiers: TemplateModifiers, val repository: SqliteRepository) {

    fun search(ctx: Context) {
        val session = ctx.requireSession()

        val q = ctx.queryParam("q")

        val documents = repository.searchDocuments(accountId = session.id, query = "%$q%")

        ctx.tempolin(
            Frame(
                modifiers = modifiers,
                title = "Overview",
                isTarget = true,
                content = Search(
                    modifiers = modifiers,
                    search = q ?: "",
                    document = {
                        documents.map { d ->
                            DocumentBlock(
                                extId = d.extId.value,
                                title = d.title,
                                referenceDate = d.referenceDate.formatHuman()
                            )
                        }.asSequence()
                    }
                )
            )
        )
    }

}